.. -*- mode: rst -*-

NOMAD - A blackbox optimization software
========================================

NOMAD is a C++ implementation of the Mesh Adaptive Direct Search algorithm
(MADS), designed for difficult blackbox optimization problems. These problems
occur when the functions defining the objective and constraints are the
result of costly computer simulations.

This version of NOMAD was modified and redistributed under the rules of LGPL.

Copyright of original (v4.0.0-beta-2):
   * Sebastien Le Digabel, Polytechnique Montreal
   * Viviane Rochon Montplaisir, Polytechnique Montreal
   * Christophe Tribes, Polytechnique Montreal

Copyright of modifications:
   UC Regents, Berkeley

Official website:
   https://www.gerad.ca/nomad/

Reference:
   * C. Audet, S. Le Digabel, C. Tribes and V. Rochon Montplaisir. The NOMAD
     project. Software available at https://www.gerad.ca/nomad.
   * S. Le Digabel. Algorithm 909: NOMAD: Nonlinear Optimization with the MADS
     algorithm. ACM Transactions on Mathematical Software, 37(4):44:1–44:15, 2011.
